diff --git a/debian/changelog b/debian/changelog
index 0fbf0795b5efa51e54e85dbee162acde935faf75..96730cdd27b916039ee400a2a42bd1ffdc70240c 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,8 +1,13 @@
 devscripts (2.24.4) UNRELEASED; urgency=medium
 
+  [ Holger Levsen ]
   * Start 2.24.4 development. d/changelog entries will be written on
     release using the git commit messages.
 
+  [ Julien Plissonneau Duquène ]
+  * Apply uversionmangle rules to the version specified with
+    --download-version. (Closes: #1087641)
+
  -- Holger Levsen <holger@debian.org>  Tue, 12 Nov 2024 16:47:27 +0100
 
 devscripts (2.24.3) unstable; urgency=medium
diff --git a/lib/Devscripts/Uscan/WatchLine.pm b/lib/Devscripts/Uscan/WatchLine.pm
index 3ef0290430fbe237989d58c517f62adb9e9600e9..288ce1088cd6bf71a26ebd847ea24b49f56c4420 100644
--- a/lib/Devscripts/Uscan/WatchLine.pm
+++ b/lib/Devscripts/Uscan/WatchLine.pm
@@ -806,12 +806,22 @@ EOF
     if ($self->versionmode eq 'ignore' and $self->config->download_version) {
         uscan_verbose 'Ignore --download_version for component with "ignore"';
     } elsif ($self->config->download_version) {
-        $self->shared->{download_version} = $self->config->download_version;
+        my $mangled_downloadversion = $self->config->download_version;
+        if (
+            mangle(
+                $watchfile,        \$self->line,
+                'uversionmangle:', \@{ $self->uversionmangle },
+                \$mangled_downloadversion
+            )
+        ) {
+            return $self->status(1);
+        }
+        $self->shared->{download_version} = $mangled_downloadversion;
         $self->shared->{download}         = 2
           if $self->shared->{download} == 1;    # Change default 1 -> 2
         $self->badversion(1);
         uscan_verbose "Download the --download-version specified version: "
-          . "$self->{shared}->{download_version}";
+          . "(uversionmangled): $self->{shared}->{download_version}";
     } elsif ($self->config->download_debversion) {
         $self->shared->{download_version} = $mangled_lastversion;
         $self->shared->{download}         = 2
